summaryrefslogtreecommitdiffstats
path: root/libkcal/incidencebase.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
commit7be55ffa061c026e35e2d6a0effe1161ddb0d41f (patch)
tree8474f9b444b2756228600050f07a7ff25de532b2 /libkcal/incidencebase.h
parentf587f20a6d09f1729dd0a8c1cd8ee0110aec7451 (diff)
downloadtdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.tar.gz
tdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1157655 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkcal/incidencebase.h')
-rw-r--r--libkcal/incidencebase.h62
1 files changed, 31 insertions, 31 deletions
diff --git a/libkcal/incidencebase.h b/libkcal/incidencebase.h
index 1cccb4dd..72455b43 100644
--- a/libkcal/incidencebase.h
+++ b/libkcal/incidencebase.h
@@ -22,18 +22,18 @@
#ifndef KCAL_INCIDENCEBASE_H
#define KCAL_INCIDENCEBASE_H
-#include <qdatetime.h>
-#include <qstringlist.h>
-#include <qvaluelist.h>
-#include <qptrlist.h>
+#include <tqdatetime.h>
+#include <tqstringlist.h>
+#include <tqvaluelist.h>
+#include <tqptrlist.h>
#include "customproperties.h"
#include "attendee.h"
namespace KCal {
-typedef QValueList<QDate> DateList;
-typedef QValueList<QDateTime> DateTimeList;
+typedef TQValueList<TQDate> DateList;
+typedef TQValueList<TQDateTime> DateTimeList;
class Event;
class Todo;
class Journal;
@@ -106,21 +106,21 @@ class LIBKCAL_EXPORT IncidenceBase : public CustomProperties
*/
virtual bool accept(Visitor &) { return false; }
- virtual QCString type() const = 0;
+ virtual TQCString type() const = 0;
/** Set the unique id for the event */
- void setUid( const QString & );
+ void setUid( const TQString & );
/** Return the unique id for the event */
- QString uid() const;
+ TQString uid() const;
/** Sets the time the incidence was last modified. */
- void setLastModified( const QDateTime &lm );
+ void setLastModified( const TQDateTime &lm );
/** Return the time the incidence was last modified. */
- QDateTime lastModified() const;
+ TQDateTime lastModified() const;
/** sets the organizer for the event */
void setOrganizer( const Person &o );
- void setOrganizer( const QString &o );
+ void setOrganizer( const TQString &o );
Person organizer() const;
/** Set readonly status. */
@@ -128,19 +128,19 @@ class LIBKCAL_EXPORT IncidenceBase : public CustomProperties
/** Return if the object is read-only. */
bool isReadOnly() const { return mReadOnly; }
- /** for setting the event's starting date/time with a QDateTime. */
- virtual void setDtStart( const QDateTime &dtStart );
- /** returns an event's starting date/time as a QDateTime. */
- virtual QDateTime dtStart() const;
+ /** for setting the event's starting date/time with a TQDateTime. */
+ virtual void setDtStart( const TQDateTime &dtStart );
+ /** returns an event's starting date/time as a TQDateTime. */
+ virtual TQDateTime dtStart() const;
/** returns an event's starting time as a string formatted according to the
users locale settings */
- virtual QString dtStartTimeStr() const;
+ virtual TQString dtStartTimeStr() const;
/** returns an event's starting date as a string formatted according to the
users locale settings */
- virtual QString dtStartDateStr( bool shortfmt = true ) const;
+ virtual TQString dtStartDateStr( bool shortfmt = true ) const;
/** returns an event's starting date and time as a string formatted according
to the users locale settings */
- virtual QString dtStartStr() const;
+ virtual TQString dtStartStr() const;
virtual void setDuration( int seconds );
int duration() const;
@@ -164,7 +164,7 @@ class LIBKCAL_EXPORT IncidenceBase : public CustomProperties
*
* @param comment The comment to add.
*/
- void addComment(const QString& comment);
+ void addComment(const TQString& comment);
/**
* Remove a comment from the event.
@@ -174,13 +174,13 @@ class LIBKCAL_EXPORT IncidenceBase : public CustomProperties
*
* @return true if match found, false otherwise.
*/
- bool removeComment( const QString& comment );
+ bool removeComment( const TQString& comment );
/** Delete all comments associated with this incidence. */
void clearComments();
/** Return all comments associated with this incidence. */
- QStringList comments() const;
+ TQStringList comments() const;
/**
Add Attendee to this incidence. IncidenceBase takes ownership of the
@@ -205,16 +205,16 @@ class LIBKCAL_EXPORT IncidenceBase : public CustomProperties
/**
Return the Attendee with this email address.
*/
- Attendee *attendeeByMail( const QString & ) const;
+ Attendee *attendeeByMail( const TQString & ) const;
/**
Return first Attendee with one of the given email addresses.
*/
- Attendee *attendeeByMails( const QStringList &,
- const QString &email = QString::null ) const;
+ Attendee *attendeeByMails( const TQStringList &,
+ const TQString &email = TQString::null ) const;
/**
Return attendee with given uid.
*/
- Attendee *attendeeByUid( const QString &uid ) const;
+ Attendee *attendeeByUid( const TQString &uid ) const;
/**
Pilot synchronization states
@@ -266,12 +266,12 @@ class LIBKCAL_EXPORT IncidenceBase : public CustomProperties
private:
// base components
- QDateTime mDtStart;
+ TQDateTime mDtStart;
Person mOrganizer;
- QString mUid;
- QDateTime mLastModified;
+ TQString mUid;
+ TQDateTime mLastModified;
Attendee::List mAttendees;
- QStringList mComments;
+ TQStringList mComments;
bool mFloats;
@@ -282,7 +282,7 @@ class LIBKCAL_EXPORT IncidenceBase : public CustomProperties
unsigned long mPilotId; // unique id for pilot sync
int mSyncStatus; // status (for sync)
- QPtrList<Observer> mObservers;
+ TQPtrList<Observer> mObservers;
class Private;
Private *d;